singe-core 0.1.0-alpha.5

Shared utilities for Singe crates.
docs.rs failed to build singe-core-0.1.0-alpha.5
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: singe-core-0.1.0-alpha.1

singe-core

Shared macros and small FFI utility helpers used by Singe wrapper crates.

This crate shouldn't be used directly.